==> react-form-builder-3.2.0.tgz: package/lib/ProxyField/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { field } from '../prop-types';
import { FIELDS } from '../Standard'; // fields

import TextField from '../Standard/Fields/Text';
import NumericField from '../Standard/Fields/Numeric';
import FieldSetField from '../Standard/Fields/FieldSet';
import PickerField from '../Standard/Fields/Picker';

var ProxyField = function ProxyField(_ref) {
  var field = _ref.field,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      fieldSize = _ref.fieldSize,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var Field;

  switch (field.type) {
    case FIELDS.TEXT:
      Field = TextField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    case FIELDS.NUMERIC:
      Field = NumericField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    case FIELDS.FIELDSET:
      Field = FieldSetField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    case FIELDS.PICKER:
      Field = PickerField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    default:
      {
        var rendererResponse = renderer({
          id: field.id,
          innerProps: {
            field: field,
            tabIndex: tabIndex,
            onChange: onChange,
            onBlur: onBlur,
            errors: errors,
            alerts: alerts
          }
        });

        if (React.isValidElement(rendererResponse)) {
          Field = rendererResponse;
        } else {
          Field = /*#__PURE__*/React.createElement("p", null, "Unknown Field type ", /*#__PURE__*/React.createElement("span", null, field.type));
        }

        break;
      }
  }

  return Field;
};

ProxyField.displayName = 'ProxyField';
export default ProxyField;

==> react-form-builder-4.0.0.tgz: package/lib/ProxyField/index.js <==
import React from 'react';
import { field } from '../prop-types';
import { FIELDS } from '../Standard'; // fields

import TextField from '../Standard/Fields/Text';
import NumericField from '../Standard/Fields/Numeric';
import FieldSetField from '../Standard/Fields/FieldSet';
import PickerField from '../Standard/Fields/Picker';

var ProxyField = function ProxyField(_ref) {
  var field = _ref.field,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      fieldSize = _ref.fieldSize,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var Field;

  switch (field.type) {
    case FIELDS.TEXT:
      Field = TextField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    case FIELDS.NUMERIC:
      Field = NumericField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    case FIELDS.FIELDSET:
      Field = FieldSetField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    case FIELDS.PICKER:
      Field = PickerField({
        field: field,
        tabIndex: tabIndex,
        onChange: onChange,
        onBlur: onBlur,
        errors: errors,
        alerts: alerts,
        renderer: renderer
      });
      break;

    default:
      {
        var rendererResponse = renderer({
          id: field.id,
          innerProps: {
            field: field,
            tabIndex: tabIndex,
            onChange: onChange,
            onBlur: onBlur,
            errors: errors,
            alerts: alerts
          }
        });

        if ( /*#__PURE__*/React.isValidElement(rendererResponse)) {
          Field = rendererResponse;
        } else {
          Field = /*#__PURE__*/React.createElement("p", null, "Unknown Field type ", /*#__PURE__*/React.createElement("span", null, field.type));
        }

        break;
      }
  }

  return Field;
};

ProxyField.displayName = 'ProxyField';
export default ProxyField;
